﻿#include "motor.h"

bool motor::init_flag0 = true;
bool motor::init_flag1 = true;

motor::motor(int index)
	:id(index),duty(0.0),cw(0),free(0)
{
	switch(id){
		case 0:
			if (init_flag0){
				init_flag0 = false;
				
				#if F_CPU == 1000000UL
					TCCR2B = 0x09;
				#elif F_CPU == 8000000UL
					TCCR2B = 0x0A;
				#else
					#error Motor0::error
				#endif
			
				TCCR2A = 0x23;
				DDRD = (1<<DDD2)|(1<<DDD3)|(1<<DDD4)|(DDRD & 0xEC);
				OCR2A = 99;
			}
			break;
		
		case 1 :
			if(init_flag1){
				init_flag1 = false;
			
				#if F_CPU == 1000000UL
					TCCR0B = 0x09;
				#elif F_CPU == 8000000UL
					TCCR0B = 0x0A;
				#else
					#error Motor1::error
				#endif
			
				TCCR0A = 0x23;
				DDRD = (1<<DDD5)|(1<<DDD6)|(1<<DDD7)|(DDRD & 0x1F);
				OCR0A = 99;
			}
			break;
		default:
			break;
	}
}

double motor::getDuty() const{
	return duty;
}

int motor::getCw() const{
	return cw;
}

int motor::getFree() const{
	return free;
}

void motor::setDuty(double d){
	
	//高速化、不要な値の除去
	if(d == duty || d < 0.0 || d > 1.0)
		return;
		
	duty = d;
	switch(id){
		case 0 :
			OCR2B = (int)(97.0 * duty) + 1;
			break;
		case 1 :
			OCR0B = (int)(97.0 * duty) + 1;
			break;
		default:
			break;
	}
}

void motor::setCw(int c){
	
	//高速化、不適切な値を省く
	if(c == cw || (c != 0 && c != 1))
		return;
	
	cw = c;
	switch(id){
		case 0:
			PORTD = (cw<<PORTD2)|(PORTD & 0xFB);
			break;
		case 1:
			PORTD = (cw<<PORTD6)|(PORTD & 0xBF);
			break;
		default:
			break;
	}
}

void motor::setFree(int f){
	
	//高速化、不適切な値を省く
	if(f == free || (f != 0 && f != 1))
		return;

	free = f;	
	switch(id){
		case 0:
			PORTD = (free<<PORTD4)|(PORTD & 0xEF);
			break;
		case 1:
			PORTD = (free<<PORTD7)|(PORTD & 0x7F);
			break;
		default:
			break;
	}
}